#!/bin/sh
#  Author: Paul Hardwick
# Company: Novell Inc.
# Purpose: This is a script to allow Novell Technical Support the ability
#          to forcefully remove Novell eDirectory from a UNIX server.
#          It is structured to be cross platform for the different varieties
#          of UNIX that Novell eDirectory runs on.
# Comment: This script will NOT backup any data. This should only be used
#          under the direction of Novell Technical Support.
#
# Code Standard: To allow the script to run on multiple platforms, ensure that
#		 functions follow the following standard:
#
#                # Comment describing what the function does
# 		 functionName()
#		 {
#			doActionsInsideFunction
#		 }

# General script variables
setVars_General()
{
	VERSION_MAJOR=1
	VERSION_MINOR=2
	VERSION_REVISION=12
	VERSION="$VERSION_MAJOR.$VERSION_MINOR.$VERSION_REVISION"
	TITLE="Novell Scrub Script"
#	COMMENT="*********************************************************************
#***            This script is currently being developed.          ***           
#*** For issues please contact Paul Hardwick PHardwick@Novell.com  ***
#*********************************************************************
#"
	# Supported Operating Systems for this script
	SUPPORTED_OS="Linux SunOS HPUX AIX"

	# Null Device
	NULLDEV=/dev/null

	# Default Variables for eDirectory
	EDIR_DEFAULT_NDSCONF="/nds.conf"
	EDIR_DEFAULT_MODULESLIB="/nds-modules"

	EDIR_DEFAULT_CONFIGDIR="/etc"
	EDIR_DEFAULT_DIBDIR="/var/nds/dib"
	EDIR_DEFAULT_LIBDIR="/usr/lib"
	EDIR_DEFAULT_VARDIR="/var/nds"

	# Default CMD Variables
	CMD_HOSTOS="uname -s"
	CMD_DELETEFILEORDIRECTORY="rm -rf"

	# Regexp for finding Novell packages
	NOVELL_PACKAGES="NOVL|NDS|NLDAP|novell|ntls|IBMJava2"
	
	# List of processes that will be killed (This will be used to do a grep against ps -ef)
	PROCESS_LIST="ndsrepair ndstrace ndsdump ndsconfig ndsmerge ldapconfig nmasconfig slpuasa nds_uamcd nds_ssod ConsoleOne ndsd novell namcd nscd"	

	# Starting Stage number
	STAGE=0

	# Failure Counts
	FAILURE_COUNT=0
	FAILURE_TOTAL=0
}
##### Start of Host OS specific Variables #####
# Set the Linux specific variables
setVars_Linux()
{
	FULLHOSTNAME="`hostname --long`"
	PKG_LIST="IBMJava2 NDSadmloc NDSadmutl NDSbase NDScmnloc NDScommon NDSdelim NDSdump NDSdxevnt NDSimnloc NDSimon NDSldap NDSmasloc NDSmasv NDSndsdrv NDSnmas NDSntsdrv NDSrdxml NDSremote NDSrepair NDSsdns NDSsdxml NDSsecur NDSsecutl NDSserv NDSsfrep NDSsfrep_fr NDSsfrep_ja NDSsfrep_zh_CN NDSsfrep_zh_TW NDSsice NDSsice_fr NDSsice_ja NDSsice_zh_CN NDSsice_zh_TW NDSsimgr NDSsimgr_fr NDSsimgr_ja NDSsimgr_zh_CN NDSsimgr_zh_TW NDSsldap NDSsldap_fr NDSsldap_ja NDSsldap_zh_CN NDSsldap_zh_TW NDSslp NDSslploc NDSspki NDSspki_fr NDSspki_ja NDSspki_zh_CN NDSspki_zh_TW NDSsrvloc NDSsslp NDSsslp_fr NDSsslp_ja NDSsslp_zh_CN NDSsslp_zh_TW NDSsuam NDSswan NDSswan_fr NDSswan_ja NDSswan_zh_CN NDSswan_zh_TW NDSuam NOVLam NDSxbase NDSxml nici NLDAPbase NOVLc1 NOVLc1_fr NOVLc1_ja NOVLc1_zh_CN NOVLc1_zh_TW NLDAPsdk NOVLembox NOVLice NOVLlmgnt NOVLnmas NOVLpkia NOVLpkis NOVLpkit NOVLsas NOVLsnmp NOVLstlog NOVLsubag NOVLxis ntls NDSjdbc NDSsap NDSwflow NOVLjvml"
	CMD_SINGLE_PKG_INSTALL_CHECK="rpm -q"
	CMD_LIST_ALL_PACKAGES="rpm -qa"
	CMD_SINGLE_PKG_REMOVE="rpm --erase --nodeps --noscripts"
	CMD_PKG_NAME_EXTRACT="grep -v \"\""
}
# Set the SunOS specific variables
setVars_SunOS()
{
	FULLHOSTNAME="`hostname`.`domainname`"
	
	PKG_LIST="IBMJava2 NDSadmloc NDSadmutl NDSbase NDScmnloc NDScommon NDSdelim NDSdump NDSdxevnt NDSimnloc NDSimon NDSldap NDSmasloc NDSmasv NDSndsdrv NDSnmas NDSntsdrv NDSrdxml NDSremote NDSrepair NDSsdns NDSsdxml NDSsecur NDSsecutl NDSserv NDSsfrep NDSsfrep_fr NDSsfrep_ja NDSsfrep_zh_CN NDSsfrep_zh_TW NDSsice NDSsice_fr NDSsice_ja NDSsice_zh_CN NDSsice_zh_TW NDSsimgr NDSsimgr_fr NDSsimgr_ja NDSsimgr_zh_CN NDSsimgr_zh_TW NDSsldap NDSsldap_fr NDSsldap_ja NDSsldap_zh_CN NDSsldap_zh_TW NDSslp NDSslploc NDSspki NDSspki_fr NDSspki_ja NDSspki_zh_CN NDSspki_zh_TW NDSsrvloc NDSsslp NDSsslp_fr NDSsslp_ja NDSsslp_zh_CN NDSsslp_zh_TW NDSsuam NDSswan NDSswan_fr NDSswan_ja NDSswan_zh_CN NDSswan_zh_TW NDSuam NOVLam NDSxbase NDSxml nici NLDAPbase NOVLc1 NOVLc1_fr NOVLc1_ja NOVLc1_zh_CN NOVLc1_zh_TW NLDAPsdk NOVLembox NOVLice NOVLlmgnt NOVLnmas NOVLpkia NOVLpkis NOVLpkit NOVLsas NOVLsnmp NOVLstlog NOVLsubag NOVLxis ntls NDSjdbc NDSsap NDSwflow NOVLjvml"
        CMD_SINGLE_PKG_INSTALL_CHECK="pkginfo"
	CMD_LIST_ALL_PACKAGES="pkginfo"
	CMD_PKG_NAME_EXTRACT="cut -b 13-27"

	SUNOS_PKG_ADMIN_FILE="/tmp/.novell-scrub"

	CMD_SINGLE_PKG_REMOVE="pkgrm -n -a $SUNOS_PKG_ADMIN_FILE"

	# Create the admin file for removing packages automatically
	echo '#ident \"@(#)default  1.4 92/12/23 SMI\" /* SVr4.0  1.5.2.1 */' > $SUNOS_PKG_ADMIN_FILE
	echo "mail="	 		>> $SUNOS_PKG_ADMIN_FILE
	echo "instance=unique"		>> $SUNOS_PKG_ADMIN_FILE
	echo "partial=ask"		>> $SUNOS_PKG_ADMIN_FILE
	echo "runlevel=ask"		>> $SUNOS_PKG_ADMIN_FILE
	echo "idepend=nocheck"		>> $SUNOS_PKG_ADMIN_FILE
	echo "rdepend=nocheck"		>> $SUNOS_PKG_ADMIN_FILE
	echo "space=ask"		>> $SUNOS_PKG_ADMIN_FILE
	echo "setuid=ask"		>> $SUNOS_PKG_ADMIN_FILE
	echo "conflict=nocheck"		>> $SUNOS_PKG_ADMIN_FILE
	echo "action=nocheck"		>> $SUNOS_PKG_ADMIN_FILE
	echo "basedir=default"		>> $SUNOS_PKG_ADMIN_FILE
}

# Set the HP-UX specific variables
setVars_HPUX()
{
	FULLHOSTNAME="`hostname`.`domainname`"
	PKG_LIST="IBMJava2 NDSadmloc NDSadmutl NDSbase NDScmnloc NDScommon NDSdelim NDSdump NDSdxevnt NDSimnloc NDSimon NDSldap NDSmasloc NDSmasv NDSndsdrv NDSnmas NDSntsdrv NDSrdxml NDSremote NDSrepair NDSsdns NDSsdxml NDSsecur NDSsecutl NDSserv NDSsfrep NDSsfrep_fr NDSsfrep_ja NDSsfrep_zh_CN NDSsfrep_zh_TW NDSsice NDSsice_fr NDSsice_ja NDSsice_zh_CN NDSsice_zh_TW NDSsimgr NDSsimgr_fr NDSsimgr_ja NDSsimgr_zh_CN NDSsimgr_zh_TW NDSsldap NDSsldap_fr NDSsldap_ja NDSsldap_zh_CN NDSsldap_zh_TW NDSslp NDSslploc NDSspki NDSspki_fr NDSspki_ja NDSspki_zh_CN NDSspki_zh_TW NDSsrvloc NDSsslp NDSsslp_fr NDSsslp_ja NDSsslp_zh_CN NDSsslp_zh_TW NDSsuam NDSswan NDSswan_fr NDSswan_ja NDSswan_zh_CN NDSswan_zh_TW NDSuam NOVLam NDSxbase NDSxml nici NLDAPbase NOVLc1 NOVLc1_fr NOVLc1_ja NOVLc1_zh_CN NOVLc1_zh_TW NLDAPsdk NOVLembox NOVLice NOVLlmgnt NOVLnmas NOVLpkia NOVLpkis NOVLpkit NOVLsas NOVLsnmp NOVLstlog NOVLsubag NOVLxis ntls NDSjdbc NDSsap NDSwflow NOVLjvml"
        CMD_SINGLE_PKG_INSTALL_CHECK="swlist"
	CMD_LIST_ALL_PACKAGES="swlist -a product"
	CMD_PKG_NAME_EXTRACT="grep -v \"\""
	CMD_SINGLE_PKG_REMOVE="swremove -x enforce_dependencies=false"
}

# Set the AIX specific variables
setVars_AIX()
{
	FULLHOSTNAME="`hostname`.`domainname`"
	PKG_LIST="NDS.NDSadmutl NDS.NDSserv NDS.NDSbase NDS.NDScommon NDS.NDSdump NDS.NDSimon NDS.NDSldap NDS.NDSmasv NDS.NDSnmas NDS.NDSrepair NDS.NDSsecur NDS.NDSsecutl NDS.NDSslp NDS.NLDAPbase NOVLniu0 NDS.NLDAPsdk NOVLembox NDS.NOVLice NDS.NOVLlmgnt NOVLnmas NOVLntls NOVLpkia NOVLpkis NOVLpkit NDS.NOVLsas NDS.NOVLsnmp NDS.NOVLstlog NDS.NOVLsubag NDS.NOVLxis"
        CMD_SINGLE_PKG_INSTALL_CHECK="lslpp -l"
	CMD_LIST_ALL_PACKAGES="lslpp -l -c"
	CMD_PKG_NAME_EXTRACT="cut -d : -f 2"
	CMD_SINGLE_PKG_REMOVE="installp -ug"
}
##### End of Host OS Variables #####

##### Set eDirectory Variables #####

# Set the eDirectory variables from /etc/nds.conf
setVars_eDir()
{
	if [ -f "$EDIR_DEFAULT_CONFIGDIR$EDIR_DEFAULT_NDSCONF" ] 
	then
		EDIR_CONFIGDIR="`cat $EDIR_DEFAULT_CONFIGDIR$EDIR_DEFAULT_NDSCONF|grep -v \"^#\"|grep n4u.server.configdir|cut -d = -f 2`"
		if [ "$EDIR_CONFIGDIR" = "" ]
		then
			EDIR_CONFIGDIR=$EDIR_DEFAULT_CONFIGDIR$EDIR_DEFAULT_NDSCONF
		fi

		EDIR_DIBDIR="`cat $EDIR_CONFIGDIR|grep -v \"^#\"|grep n4u.nds.dibdir|cut -d = -f 2`"
		if [ "$EDIR_DIBDIR" = "" ]
		then
			EDIR_DIBDIR=$EDIR_DEFAULT_DIBDIR
		fi

		EDIR_VARDIR="`cat $EDIR_CONFIGDIR|grep -v \"^#\"|grep n4u.server.vardir|cut -d = -f 2`"
        	if [ "$EDIR_VARDIR" = "" ]
	        then
        	        EDIR_VARDIR=$EDIR_DEFAULT_VARDIR
	        fi


		EDIR_LIBDIR="`cat $EDIR_CONFIGDIR|grep -v \"^#\"|grep n4u.server.libdir|cut -d = -f 2`"
	        if [ "$EDIR_LIBDIR" = "" ]
	        then
        	        EDIR_LIBDIR=$EDIR_DEFAULT_LIBDIR$EDIR_DEFAULT_MODULESLIB
	        else
			EDIR_LIBDIR="$EDIR_LIBDIR$EDIR_DEFAULT_MODULESLIB"
		fi
	else
		# If the /etc/nds.conf file doesn't exist then just use the defaults
		EDIR_CONFIGDIR=$EDIR_DEFAULT_CONFIGDIR$EDIR_DEFAULT_NDSCONF
		EDIR_DIBDIR=$EDIR_DEFAULT_DIBDIR
		EDIR_VARDIR=$EDIR_DEFAULT_VARDIR
       	        EDIR_LIBDIR=$EDIR_DEFAULT_LIBDIR$EDIR_DEFAULT_MODULESLIB	
	fi
}

##### Set the ANSI colours #####
# Enable or disable ANSI colours
# Input: $1="ON" or "OFF"
setANSIColours()
{
	if [ -z "$1" ]
	then
		dispError "Internal Error:  setANSIColours() was not passed a parameter."
		abortScript "1"
	else
		case $1 in
		"on" |"ON")
			enableANSIColours;;
		"off" |"OFF")
			disableANSIColours;;
		*)
			dispError "Internal Error:  setANSIColours() was passed an invalid parameter of '$1'."
			abortScript "1"
		esac
	fi
}

enableANSIColours()
{
  esc=""

  fgblack="${esc}[30m";   fgred="${esc}[31m";    fggreen="${esc}[32m";
  fgyellow="${esc}[33m";  fgblue="${esc}[34m";   fgpurple="${esc}[35m";
  fgcyan="${esc}[36m";    fgwhite="${esc}[37m";
  
  bgblack="${esc}[40m";   bgred="${esc}[41m";   bggreen="${esc}[42m";
  bgyellow="${esc}[43m";  bglue="${esc}[44m";   bgpurple="${esc}[45m";
  bgcyan="${esc}[46m";    bgwhite="${esc}[47m";

  boldon="${esc}[1m";    boldoff="${esc}[22m";
  italicson="${esc}[3m"; italicsoff="${esc}[23m";
  ulon="${esc}[4m";      uloff="${esc}[24m";
  invon="${esc}[7m";     invoff="${esc}[27m";

  reset="${esc}[0m";

  resultok=${boldon}${fggreen}
  resultfail=${boldon}${fgred}
}

# Disable the ANSI colours
disableANSIColours()
{

  fgblack="";   fgred="";    fggreen="";
  fgyellow="";   fgblue="";   fgpurple="";
  fgcyan="";    fgwhite="";
  
  bgblack="";   bgred="";   bggreen="";
  bgyellow="";   bglue="";   bgpurple="";
  bgcyan="";    bgwhite="";

  boldon="";    boldoff="";
  italicson=""; italicsoff="";
  ulon="";      uloff="";
  invon="";     invoff="";

  reset="";
  resultok="";
  resultfail="";

}

# Reset the ANSI colours on the terminal back to normal
resetANSIcolours()
{
	echo ${reset}
}
##### End of the ANSI colours #####




##### Start of Auxillary Functions #####
# Determine which OS the script is being run on
# Output: OS contains operating system
getHostOS()
{
	OS="`$CMD_HOSTOS`"

	# Convert HP-UX to HPUX as function or variable names don't like hyphens in them
	if [ "$OS" = "HP-UX" ]
	then
		OS="HPUX"
	fi
}

# Verify the the host OS that this script is executing on is supported
# by the script
verifySupportedOS()
{
	for CHECKOS in $SUPPORTED_OS
        do
		if [ "$OS" = "$CHECKOS" ]
              	then
			return 1
		fi
	done
	echo "Sorry, the \"$OS\" operating system is not supported by this script."
	exit 1
}

# Display the script title
dispTitle()
{
	clear
	printf "${boldon}${fgwhite}%-20s -= $TITLE for $OS $VERSION =-${reset}\n" ""
	if [ "$COMMENT" != "" ]
	then
		echo "$COMMENT"
	fi
}

# Display the warning message of Terms and Conditions
dispTermsAndConditions()
{
	frame="${boldon}${fgcyan}"
	text="${boldon}${fgwhite}"
	echo "${frame}+------------------------------------------------------------------------------+"
	echo "|${fgyellow}                              Terms And Conditions                            ${frame}|"
	echo "+------------------------------------------------------------------------------+"
	echo "|${text}  This script is not for general public use.  It should only be used under    ${frame}|"
	echo "|${text}  the direction of engineers from Novell Technical Support.  By running this  ${frame}|"
	echo "|${text}  script you agree that you are responsible for all costs necessary to        ${frame}|"
	echo "|${text}  resolve any problems resulting from the use of this script.                 ${frame}|"
	echo "|                                                                              |"
	echo "|${text}  This script will forcefully remove packages and files associated with any   ${frame}|"
	echo "|${text}  version of eDirectory (including DIB files), DirXML, ConsoleOne, NMAS,      ${frame}|"
	echo "|${text}  NICI, iMonitor, Account Management, NSure Audit, iManager and Novell        ${frame}|"
	echo "|${text}  Nterprise Linux Services.                                                   ${frame}|"
	echo "|                                                                              |"
	echo "|${text}  NDS and any daemons associated with the above products will be terminated.  ${frame}|"
	echo "|                                                                              |"
	echo "|  ${boldon}${fgred}ENSURE YOU HAVE A CURRENT SYSTEM BACKUP! NO DECONFIGURATION OF PRODUCTS     ${frame}|"
	echo "|  ${boldon}${fgred}WILL BE DONE.  THIS SCRIPT DOES **NOT** BACKUP ANY FILES AT ALL.            ${frame}|"
	echo "+------------------------------------------------------------------------------+${reset}"
	
}

# Prompt the user to type "I Agree" to continue 
promptForIAgreeToTermsAndConditions()
{
	printf "%s" "${boldon}Type in the words '${fgyellow}I Agree${fgwhite}' to continue:${reset} "
	INPUT=
	read INPUT
	if [ "$INPUT" = "I Agree" ]
	then
		return 0
	fi
	echo
	echo "${fgred}You did not agree to the Terms and Conditions. The script has been aborted.${reset}"
	exit 0
}

# Display a message letting the user know they have agree'd to the terms and conditions
dispTermsAndConditionsAccepted()
{
	echo
	echo "You have agreed to accept these terms and conditions. The script will now scrub"
	echo "your system: $FULLHOSTNAME"
	echo
}

# Increment the total number of failurs
failure()
{
	FAILURE_COUNT="`expr $FAILURE_COUNT + 1`"
}
##### End of Auxillary Functions #####


##### Start of Action Functions #####
# Display the status of the packages: eg: INSTALLED, NOT INSTALLED
showPackagesInstallStatus()
{
	# Display header
	dispHeader "Package Name"

	for PKG in $PKG_LIST
	do
		# Display the package name
		dispItem "$PKG"

		INSTALLED=
		# Command to check if a single package is installed, redirecting
		# stdout and errout to the null device
		$CMD_SINGLE_PKG_INSTALL_CHECK $PKG 1>$NULLDEV 2>$NULLDEV
		INSTALLED=$?
		if [ "$INSTALLED" = "0" ]
		then
			PKGSTATUS="${resultok}  INSTALLED  ${reset}"
		else
			PKGSTATUS="      -      "
		fi
	
		# Display the package status result
		dispResult "$PKGSTATUS"
	done
}

# Get the packages dynamically and populates package names into DYN_PKG_LIST
getPackagesDynamically()
{
	# Get the packages installed and put them into DYN_PKG_LIST
	DYN_PKG_LIST=`$CMD_LIST_ALL_PACKAGES | egrep $NOVELL_PACKAGES | $CMD_PKG_NAME_EXTRACT | sort | uniq`

	# Set the main PKG_LIST to the Dynmically generated one
	PKG_LIST=$DYN_PKG_LIST
}

# Forcefully remove the packages. Check package exists first
removePackagesForcefully()
{
	# Display package status header
	dispHeader "Package Name"

	for PKG in $PKG_LIST
	do
		# Display the package name
		dispItem "$PKG"
		# Check if the package is firstly installed. If so then remove it
		INSTALLED=
		$CMD_SINGLE_PKG_INSTALL_CHECK $PKG 1>$NULLDEV 2>$NULLDEV
#		$CMD_SINGLE_PKG_INSTALL_CHECK $PKG 
		INSTALLED=$?
		if [ "$INSTALLED" = "0" ]
		then
			# Command to forcefully remove a single package, redirecting
			# stdout and errout to the null device
			REMOVED=
			$CMD_SINGLE_PKG_REMOVE $PKG 1>$NULLDEV 2>$NULLDEV
			REMOVED=$?
			if [ "$REMOVED" = "0" ]
			then
				PKGSTATUS="${resultok}   REMOVED   ${reset}"
			else
				PKGSTATUS="${resultfail}REMOVE FAILED${reset}"
				failure
			fi
		else
			PKGSTATUS="      -      "
		fi

		# Display the package status result
		dispResult "$PKGSTATUS"
	done
}

# Delete the file or directory specified
deleteFileOrDirectory()
{
	dispItem "$1"
	DEL=

	if [ -f "$1" ]
	then
		DEL=$1
	fi

	if [ -d "$1" ]
	then
		DEL=$1
	fi

	if [ "$DEL" != "" ]
	then
		DELETED=
		$CMD_DELETEFILEORDIRECTORY $DEL 1>$NULLDEV 2>$NULLDEV
		DELETED=$?

		if [ "$DELETED" = "0" ]
		then
			DELETESTATUS="${resultok}   DELETED   ${reset}"
		else
			DELETESTATUS="${resultfail}DELETE FAILED${reset}"
			failure
		fi
	else
		DELETESTATUS="      -      "
	fi

	# Display the status of the file or directory deletion
	dispResult "$DELETESTATUS"
}

# Display the result on the right hand side of the screen - but on the left
dispResult()
{
	printf "${boldon}${fgwhite}[${boldoff}%-13s${boldon}]${reset}\n" "$1"
}

# Display the result of the right hand side of the screen - but on the right
dispResultNumber()
{
	printf "[%13s]\n" "$1"
}


# Display the item of the left hand side of the screen
dispItem()
{
	printf "${boldon}${fgwhite}%-65s${reset}" "$1" 
}

# Display the stage status and add the previous stages info to the summary
dispStage()
{
	STAGE="`expr $STAGE + 1`"

	STAGE_DESCRIPTION="`printf \"Stage [%02d]: ${fgyellow}%-64s${fgwhite}\n\" \"$STAGE\" \"$1...\"`"

	echo
	echo "${boldon}${fgwhite}+------------------------------------------------------------------------------+"
	echo "| $STAGE_DESCRIPTION |" 
	echo "+------------------------------------------------------------------------------+${reset}"
}

# Stores the failure counts for each stage
recordStageFailureTotals()
{
	FAILURE_STAGES_COUNT="$FAILURE_STAGES_COUNT $FAILURE_COUNT"
}

# Display the header for the section being processed
dispHeader()
{
	printf "${boldon}${fgwhite}| %-63s%-13s\n" "$1" "Result        |"	
	echo "+------------------------------------------------------------------------------+${reset}"
}

# This kills the processes so that they aren't running when the packages and files are removed
killProcesses()
{
	dispHeader "Process name"

	for PROC_NAME in $PROCESS_LIST
	do
		dispItem $PROC_NAME
		PIDS="`ps -ef | grep \"$PROC_NAME\" | grep -v grep | grep -v $0 | awk '{ print $2 }'`"

		if [ "$PIDS" = "" ]
		then
			KILLSTATUS="      -      "
		else
			kill -KILL $PIDS 1>$NULLDEV 2>$NULLDEV
			KILLED=$?
			if [ "$KILLED" = "0" ]
			then
				KILLSTATUS="${resultok}    KILLED   ${reset}"
			else
				KILLSTATUS="${resultfail}  NOT KILLED${reset} "
				failure
			fi
		fi
	
		dispResult "$KILLSTATUS"
	done
}


# Delete files and Directories
deleteEverything()
{
	dispHeader "File/Directory"

	deleteFileOrDirectory /var/nds
	deleteFileOrDirectory /var/ndsuam
	deleteFileOrDirectory /var/novell
	deleteFileOrDirectory /var/n4u
	deleteFileOrDirectory /var/nici
	deleteFileOrDirectory /var/.edir_upgrade
	deleteFileOrDirectory /usr/share/nwlocale
	deleteFileOrDirectory /usr/lib/nds-modules
	deleteFileOrDirectory /usr/lib/imon
	deleteFileOrDirectory /etc/n4u
	deleteFileOrDirectory /etc/pam.d.nds
	deleteFileOrDirectory /usr/ldaptools
	deleteFileOrDirectory /usr/share/man/pt_BR
	deleteFileOrDirectory /usr/ConsoleOne
	deleteFileOrDirectory /usr/lib/dirxml
	deleteFileOrDirectory /dirxml
	deleteFileOrDirectory /var/.ndsso_unixsock
	deleteFileOrDirectory /var/*install.log
	deleteFileOrDirectory /etc/.nds_uamcd_sock
	deleteFileOrDirectory /etc/nds.conf.bak
	deleteFileOrDirectory /etc/nds.conf
	deleteFileOrDirectory /etc/hosts.nds
	deleteFileOrDirectory /etc/nici.cfg
	deleteFileOrDirectory /usr/lib/libnss_nds.so.0
	deleteFileOrDirectory /usr/sbin/nds-uninstall
	deleteFileOrDirectory /usr/sbin/dirxml-uninstall
	deleteFileOrDirectory /usr/sbin/c1-uninstall
	deleteFileOrDirectory /usr/sbin/imon-uninstall
	deleteFileOrDirectory /usr/sbin/uam-uninstall
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/ice.mo
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/install.mo
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/license.txt
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/nds.mo
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/ndsbase.mo
	deleteFileOrDirectory /usr/lib/locale/de/LC_MESSAGES/uam.mo
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/ice.mo
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/install.mo
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/license.txt
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/nds.mo
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/ndsbase.mo
	deleteFileOrDirectory /usr/lib/locale/es/LC_MESSAGES/uam.mo
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/ice.mo
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/install.mo
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/license.txt
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/nds.mo
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/ndsbase.mo
	deleteFileOrDirectory /usr/lib/locale/fr/LC_MESSAGES/uam.mo
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/ice.mo
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/install.mo
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/license.txt
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/nds.mo
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/ndsbase.mo
	deleteFileOrDirectory /usr/lib/locale/it/LC_MESSAGES/uam.mo
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/ice.mo
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/install.mo
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/license.txt
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/nds.mo
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/ndsbase.mo
	deleteFileOrDirectory /usr/lib/locale/pt_BR/LC_MESSAGES/uam.mo
	deleteFileOrDirectory /etc/nds.conf.bak
	deleteFileOrDirectory /etc/pam.conf.bak
	deleteFileOrDirectory /etc/.nds_uamcd_sock
	deleteFileOrDirectory /var/opt/novell
	deleteFileOrDirectory /etc/opt/novell
	deleteFileOrDirectory /opt/novell
	deleteFileOrDirectory /var/nds-install.log
	deleteFileOrDirectory /etc/ndssnmp
	deleteFileOrDirectory /etc/ndsimon.conf
	deleteFileOrDirectory /etc/ndsimonitor.conf
	deleteFileOrDirectory $EDIR_LIBDIR
}

# Delete the NDS DIB related files
deleteDIBFiles()
{
	dispHeader "NDS Files"
	deleteFileOrDirectory $EDIR_CONFIGDIR
	deleteFileOrDirectory $EDIR_DIBDIR
	deleteFileOrDirectory $EDIR_VARDIR
}

# Start of a stage
# Input: Name of stage
stageStart()
{
	dispStage "$1"
}

# End of a stage
stageEnd()
{
	recordStageFailureTotals
	FAILURE_COUNT=0
}


# Display the summary info
dispSummaryInfo()
{
	echo
	echo "${boldon}${fgwhite}+------------------------------------------------------------------------------+"
	echo "+                                ${fgyellow}Results Summary${fgwhite}                               +"
	echo "+------------------------------------------------------------------------------+${reset}"

	STAGE_NUMBER=0
	for STAGE_FAILURE_COUNT in $FAILURE_STAGES_COUNT
	do
		STAGE_NUMBER="`expr $STAGE_NUMBER + 1`"
		STAGE_NAME="Stage `printf \"[%02d]\" \"$STAGE_NUMBER\"`"
		FAILURE_TOTAL="`expr $FAILURE_TOTAL + $STAGE_FAILURE_COUNT`"

		dispItem "$STAGE_NAME Failures"

		if [ "$STAGE_FAILURE_COUNT" = "0" ]
		then
			dispResult "${resultok}    NONE     ${reset}"
		else
			dispResultNumber $STAGE_FAILURE_COUNT
		fi
	done

	dispItem "Total Failures"
	
	if [ "$FAILURE_TOTAL" = "0" ]
	then
		dispResult "${resultok}    NONE     ${reset}"
	else
		dispResultNumber "$FAILURE_TOTAL"
	fi

	echo
	dispItem "Final End Result"

	if [ "$FAILURE_TOTAL" = "0" ]
	then
		dispResult "${resultok}   SUCCESS   ${reset}"
		echo
		exit 0
	else
		dispResult "${resultfail}   FAILED    ${reset}"
		echo
		exit 1
	fi
}

##### End of Action Functions #####

# Check the command line to see if any command line switches were provided
checkCommandline()
{
	# As long as a command line parameter is passed, lets check it
	while [ "$#" -gt "0" ]
	do
		case $1 in
			"-n" | "--noansi")     	setANSIColours "OFF";;
        	        "-h" | "--help")        dispCommandlineHelp ;;
	                "-s" | "--show")        CMDLINE_SHOW=true;;
			"-d" | "--dyn-show")	CMDLINE_DYNSHOW=true;;
			"-i" | "--dibsonly")	REMOVE_DIBS_ONLY=true ;;
			"--IAgreeToTheTermsAndConditions")	IAGREE=true ;;
		        *)			dispCommandlineHelp ;;
		esac
		shift
	done

	if [ "$CMDLINE_SHOW" = "true" ]
	then
		dispTitle
	        stageStart "Novell product packages installation status"
	        showPackagesInstallStatus
	        stageEnd
        	dispSummaryInfo
	fi

	if [ "$CMDLINE_DYNSHOW" = "true" ]
	then
		dispTitle
		stageStart "Searching dynamically for Novell packages"
		getPackagesDynamically
		if [ -z "$PKG_LIST" ]
		then
			echo "No Novell Packages were found"
			stageEnd
		else
			showPackagesInstallStatus 
			stageEnd
		fi
		dispSummaryInfo
	fi
}

# Display the command line help
dispCommandlineHelp()
{
	setANSIColours "OFF"
	dispTitle
	echo
	echo "Syntax: $0 [options]"
	echo "Where [options] is one of the following switches:"
	echo
	echo "  -s --show"	
	echo "       Show which packages are installed and not installed on the system."
	echo 
	echo "  -d --dyn-show"
	echo "       This is the same as --show but Novell packages are found dynamically."
	echo
	echo "  -i --dibsonly"
	echo "       Removes only DIB files and does not remove packages."
	echo
	echo "  -n --noansi"
        echo "       Disable the use of ANSI colours."
	echo
	echo "     --IAgreeToTheTermsAndConditions"
	echo "       Accepts the agreement and does not prompt for \"I Agree\"."
	echo
	echo "  -h --help"
	echo "       Displays this command line help."
	echo
	exit 2
}

# Main function
main()
{
	setVars_General
	getHostOS
	verifySupportedOS
	setVars_$OS
	setVars_eDir

	setANSIColours "ON"
	checkCommandline $1 $2 $3 $4 $5 $6 $7 $8 $9
	dispTitle
	dispTermsAndConditions	
	
	# If the "I Agree" has been set on the command line then don't prompt for agreement
	if [ "$IAGREE" = "true" ]
	then
		dispTermsAndConditionsAccepted
	else
		promptForIAgreeToTermsAndConditions
		dispTermsAndConditionsAccepted
		sleep 1
	fi	

	# Perform the main operations (in 'stages')
	# Each stage number is incremented dynamically.
	stageStart "Killing running processes"
	killProcesses
	stageEnd

	if [ "$REMOVE_DIBS_ONLY" != "true" ]
	then	
		stageStart "Forcefully removing Novell packages"
		removePackagesForcefully
		stageEnd
	
		stageStart "Searching for additional Novell packages";
		getPackagesDynamically
		if [ "$PKG_LIST" != "" ]
		then
			echo "Additional Novell Packages were found"
			stageEnd

			stageStart "Forcefully removing additional Novell packages"
			removePackagesForcefully
			stageEnd
		else	
			echo "No additional Novell Packages were found"
			stageEnd
		fi

		stageStart "Deleting Novell product files"	
		deleteEverything
		stageEnd
	fi

	stageStart "Deleting NDS DIB Files"
	deleteDIBFiles
	stageEnd
	
	dispSummaryInfo
}

main $1 $2 $3 $4 $5 $6 $7 $8 $9